"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadWorkspaceDefinition = void 0;
const promises_1 = require("fs/promises");
const js_yaml_1 = __importDefault(require("js-yaml"));
const path_1 = __importDefault(require("path"));
const WorkspaceDefinitionSchema_1 = require("./schemas/WorkspaceDefinitionSchema");
async function loadWorkspaceDefinition(absolutePath) {
    const contentsStr = await (0, promises_1.readFile)(absolutePath);
    const contentsParsed = js_yaml_1.default.load(contentsStr.toString());
    const validated = await WorkspaceDefinitionSchema_1.WorkspaceDefinitionSchema.parseAsync(contentsParsed);
    return {
        _absolutePath: path_1.default.dirname(absolutePath),
        name: validated.name,
        absolutePathToInput: path_1.default.resolve(validated.input),
        plugins: validated.plugins.map((plugin) => ({
            name: plugin.name,
            version: plugin.version,
            absolutePathToOutput: plugin.output != null ? path_1.default.resolve(plugin.output) : undefined,
            config: plugin.config,
            helpers: plugin.helpers != null
                ? plugin.helpers.map((helper) => ({
                    name: helper.name,
                    version: helper.version,
                }))
                : [],
        })),
    };
}
exports.loadWorkspaceDefinition = loadWorkspaceDefinition;
//# sourceMappingURL=loadWorkspaceDefinition.js.map